Release and Version History
===========================

x.x.x (TODO)
~~~~~~~~~~~~
**Features and Improvements**

**Minor Improvements**

**Bugfixes**

**Miscellaneous**


1.0.0 (2020-03-14) First Production Ready Version
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
**Features and Improvements**

- type hint support for all method.

**Minor Improvements**

- since Python2.7 is no longer supported. but pathlib_mate still supports Python2.7, it bump ``pathlib2`` version to the latest 2.5.3

**Bugfixes**

**Miscellaneous**


0.0.11 (2017-08-31) MileStone
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
A stable, rich features, fully tested version.


0.0.1 (2016-09-07)
~~~~~~~~~~~~~~~~~~
- First release